TempoForkScheduleApiServer

Trait TempoForkScheduleApiServer 

pub trait TempoForkScheduleApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required method
    fn fork_schedule<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = RpcResult<ForkSchedule>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the TempoForkScheduleApi RPC API.

Required Methods

fn fork_schedule<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = RpcResult<ForkSchedule>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Returns the Tempo fork schedule and the currently active fork.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<P> TempoForkScheduleApiServer for TempoForkScheduleRpc<P>
where P: ChainSpecProvider<ChainSpec = TempoChainSpec> + BlockNumReader + HeaderProvider + Send + Sync + 'static,